import ErrorMessage from '@/components/ErrorMessage'
import { Spinner } from '@blueprintjs/core'
import useGetChannelLogs from '@inject/graphql/custom/useGetVisibleActionLogs'
import useInInstructor from '@inject/shared/hooks/useInInstructor'
import type { FC, MouseEventHandler } from 'react'
import { memo } from 'react'
import ActionLogTimeline from './components/ActionLogTimeline'

interface ActionLogProps {
  teamId: string
  exerciseId: string
  channelId: string
  getOnInspect: (actionLogId: string) => MouseEventHandler
}

/**
 * The component expects that the subscription is active for the given teamId
 */
const ActionLog: FC<ActionLogProps> = ({
  teamId,
  exerciseId,
  channelId,
  getOnInspect,
}) => {
  const inInstructor = useInInstructor()

  const { data, loading, error } = useGetChannelLogs(channelId, {
    variables: { teamId },
  })

  if (loading) {
    return <Spinner />
  }
  if (error) {
    return (
      <ErrorMessage>
        <h1>Error occurred!</h1>
        <p>{error.message}</p>
      </ErrorMessage>
    )
  }

  return (
    <ActionLogTimeline
      actionLogs={data.actionLogs}
      teamId={teamId}
      exerciseId={exerciseId}
      getOnInspect={getOnInspect}
      inInstructor={inInstructor}
    />
  )
}

export default memo(ActionLog)
