import { Button, Callout, InputGroup } from '@blueprintjs/core'
import type { Tool } from '@inject/graphql/fragments/Tool.generated'
import { usePerformTeamToolAction } from '@inject/graphql/mutations/PerformTeamToolAction.generated'
import { useNotifyContext } from '@inject/shared/notification/contexts/NotifyContext'
import type { KeyboardEventHandler } from 'react'
import { useState } from 'react'

interface FormProps {
  grapheneTool: Tool
  teamId: string
  setOpen(arg0: boolean): void
}

const GrapheneForm = ({ grapheneTool, teamId, setOpen }: FormProps) => {
  const { tooltipDescription, id } = grapheneTool
  const [mutate] = usePerformTeamToolAction()
  const [value, setValue] = useState<string>('')
  const { notify } = useNotifyContext()

  const mutateData = () => {
    if (value.trim() === '') {
      return
    }
    mutate({
      variables: {
        teamId,
        toolId: id || 'none',
        toolArgument: value.trim(),
      },
    })
    notify('Submitted')
    setOpen(false)
    setValue('')
  }
  const handleEnter: KeyboardEventHandler<HTMLInputElement> = e => {
    if (e.key === 'Enter') mutateData()
  }

  return (
    <Callout>
      <p>{tooltipDescription}</p>
      <InputGroup
        placeholder={grapheneTool.hint || 'Argument'}
        value={value}
        onChange={e => setValue(e.currentTarget.value)}
        onKeyDown={handleEnter}
      />
      <Button onClick={mutateData}>Submit</Button>
    </Callout>
  )
}

export default GrapheneForm
