import {
  Boundary,
  Button,
  ButtonGroup,
  Classes,
  OverflowList,
  Popover,
} from '@blueprintjs/core'
import type { Team } from '@inject/graphql/fragments/Team.generated'
import type { CSSProperties, Dispatch, FC } from 'react'
import { memo, useContext, useState } from 'react'
import ExerciseContext from '../ExerciseContext'
import type { selectedReducerActionProps } from '../Overview/selectedReducer'
import { HIGHLIGHTED_COLOR } from '../utilities'
import MilestoneCards from './MilestoneCards'
import Title from './Title'

interface MilestonesProps {
  selectedDispatch: Dispatch<selectedReducerActionProps>
}

const Milestones: FC<MilestonesProps> = ({ selectedDispatch }) => {
  const { exercise } = useContext(ExerciseContext)

  const [isOpen, setIsOpen] = useState(true)
  const [selectedId, setSelectedId] = useState<string | undefined>()

  const handleClick = (item: Team | undefined) => () => {
    setSelectedId(item?.id)
    setIsOpen(true)
  }
  const getButtonStyle = (item: Team | undefined): CSSProperties => ({
    backgroundColor: selectedId === item?.id ? HIGHLIGHTED_COLOR : undefined,
  })

  const overflowRenderer = (overflowItems: (Team | undefined)[]) => (
    <div style={{ marginLeft: 'auto' }}>
      <Popover
        content={
          <ButtonGroup vertical style={{ padding: 8 }}>
            {overflowItems.map(item => (
              <Title
                key={item?.id || 'AllTeamsTab'}
                team={item}
                onClick={handleClick(item)}
                buttonStyle={getButtonStyle(item)}
              />
            ))}
          </ButtonGroup>
        }
        position='bottom-left'
      >
        <span className={Classes.BREADCRUMBS_COLLAPSED} style={{ margin: 4 }} />
      </Popover>
    </div>
  )

  const visibleItemRenderer = (item: Team | undefined) => (
    <Title
      key={item?.id || 'AllTeamsTab'}
      team={item}
      onClick={handleClick(item)}
      buttonStyle={getButtonStyle(item)}
    />
  )

  return (
    <>
      <Button
        style={{
          float: 'right',
          backgroundColor: HIGHLIGHTED_COLOR,
          marginLeft: 12,
        }}
        minimal
        icon={isOpen ? 'chevron-up' : 'chevron-down'}
        onClick={() => setIsOpen(prev => !prev)}
      />

      <OverflowList
        style={{ alignItems: 'center', marginBottom: 8 }}
        collapseFrom={Boundary.END}
        items={[undefined, ...exercise.teams]}
        overflowRenderer={overflowRenderer}
        visibleItemRenderer={visibleItemRenderer}
      />

      {isOpen && (
        <MilestoneCards
          teamId={selectedId}
          selectedDispatch={selectedDispatch}
        />
      )}
    </>
  )
}

export default memo(
  Milestones,
  (prev, next) => prev.selectedDispatch === next.selectedDispatch
)
