import { makeVar, useReactiveVar } from '@inject/graphql/client/reactive'

export const getColormode = () =>
  localStorage.getItem('colormode') === 'true' ||
  (localStorage.getItem('colormode') === null &&
    window.matchMedia &&
    window.matchMedia('(prefers-color-scheme: dark)').matches)

const initialSettings: boolean = getColormode()

export const colormode = makeVar<boolean | null>(initialSettings)
export const useColormode = () => useReactiveVar(colormode)

function changeColor(value: boolean | null) {
  if (value === null) {
    localStorage.removeItem('colormode')
    value = getColormode()
  } else {
    localStorage.setItem('colormode', value.toString())
  }
  if (value) {
    document.body.classList.add('bp5-dark')
  } else {
    document.body.classList.remove('bp5-dark')
  }
}

changeColor(initialSettings)
colormode.onNextChange(function onNext() {
  changeColor(colormode())
  colormode.onNextChange(onNext)
})
