import { makeVar, useReactiveVar } from '@inject/graphql/client/reactive'
import type { Team } from '@inject/graphql/fragments/Team.generated'

export interface TeamState {
  team: Team
  show: boolean
  inactive: boolean
}

export interface TeamStateMap {
  [teamId: string]: TeamState
}

const key = 'teamStateMap'
const initialSettings: TeamStateMap = JSON.parse(
  localStorage.getItem(key) || '{}'
)

export const teamStateMap = makeVar<TeamStateMap>(initialSettings)
export const useTeamStateMap = () => useReactiveVar(teamStateMap)

function change(value: TeamStateMap) {
  localStorage.setItem(key, JSON.stringify(value))
}

export const toggleTeam = (teamId: string) => {
  const prev = teamStateMap() as TeamStateMap
  const chosenTeam = prev[teamId]
  teamStateMap({
    ...prev,
    [teamId]: {
      ...chosenTeam,
      show: !chosenTeam.show,
    },
  })
}

export const unsetTeams = () => {
  const prev = teamStateMap() as TeamStateMap
  teamStateMap(
    Object.fromEntries(
      Object.entries(prev).map(([key, value]) => [
        key,
        { ...value, show: false },
      ])
    )
  )
}

teamStateMap.onNextChange(function onNext() {
  change(teamStateMap())
  teamStateMap.onNextChange(onNext)
})
