import { TextArea } from '@blueprintjs/core'
import type { Dispatch, FC, SetStateAction } from 'react'
import { memo, useCallback } from 'react'

interface ContentAreaProps {
  content: string
  template?: string
  setContent: Dispatch<SetStateAction<string>>
}

const ContentArea: FC<ContentAreaProps> = ({ content, setContent }) => {
  const handleContentChange = useCallback(
    (e: React.ChangeEvent<HTMLTextAreaElement>) => {
      setContent(e.target.value)
    },
    [setContent]
  )

  // TODO: optimize defaultValue to not be updated on every render
  return (
    <TextArea
      defaultValue={content}
      style={{
        resize: 'none',
        overflowY: 'auto',
        flex: 1,
        marginBottom: '0.25rem',
      }}
      placeholder='Message'
      onChange={handleContentChange}
    />
  )
}

export default memo(ContentArea)
