import { NonIdealState, Spinner } from '@blueprintjs/core'
import { useHost } from '@inject/graphql/connection/host'
import { useGetFileInfo } from '@inject/graphql/queries/GetFileInfo.generated'
import { downloadFileUrl } from '@inject/shared/config'
import DocViewerComponent from '@inject/shared/document/viewer'
import type { FC } from 'react'
import ErrorMessage from '../ErrorMessage'

interface DocViewerProps {
  teamId: string
  fileId: string
  inInstructor: boolean
}

const DocViewer: FC<DocViewerProps> = ({ teamId, fileId, inInstructor }) => {
  const { data, loading, error } = useGetFileInfo({
    variables: { fileInfoId: fileId },
  })
  const host = useHost()

  if (loading) {
    return <Spinner />
  }
  if (error) {
    return (
      <ErrorMessage>
        <h1>Error occurred!</h1>
        <p>{error.message}</p>
      </ErrorMessage>
    )
  }
  if (!data?.fileInfo?.fileName) {
    return (
      <NonIdealState
        icon='low-voltage-pole'
        title='No data'
        description='Please wait for the data to come in'
      />
    )
  }

  return (
    <DocViewerComponent
      doc={{
        uri: downloadFileUrl(host || '', teamId, fileId, inInstructor),
        fileName: data.fileInfo.fileName,
        fileType: data.fileInfo.fileName.split('.').pop() || 'txt',
      }}
    />
  )
}

export default DocViewer
