import type { PopoverPosition } from '@blueprintjs/core'
import { Button, ButtonGroup, Divider, Popover } from '@blueprintjs/core'
import { css } from '@emotion/css'
import type { FC, ReactElement } from 'react'
import { useState } from 'react'

const sticky = css`
  position: sticky;
  top: 0;
  z-index: 10;
  background-color: white;
  padding: 5px;

  .bp5-dark & {
    background-color: #2f343c;
  }
`

interface FiltersProps {
  heading?: string
  content: string | ReactElement | undefined
  position: PopoverPosition
  onSelectAll: () => void
  onDeselectAll: () => void
}

const Filters: FC<FiltersProps> = ({
  heading,
  content,
  position,
  onSelectAll,
  onDeselectAll,
}) => {
  const [open, setOpen] = useState(false)

  return (
    <Popover
      minimal
      position={position}
      content={
        <div>
          <div className={sticky}>
            <ButtonGroup minimal>
              <Button onClick={onSelectAll}>Select all</Button>
              <Divider />
              <Button onClick={onDeselectAll}>Deselect all</Button>
            </ButtonGroup>

            <Divider />
          </div>

          <div
            style={{
              minWidth: 300,
              maxHeight: 300,
              padding: '0 10px',
              overflowY: 'auto',
            }}
          >
            {content}
          </div>
        </div>
      }
      isOpen={open}
      onClose={() => setOpen(false)}
    >
      <Button icon='filter' minimal onClick={() => setOpen(true)}>
        {heading}
      </Button>
    </Popover>
  )
}

Filters.defaultProps = {
  heading: 'Filters',
}

export default Filters
