import { Divider } from '@blueprintjs/core'
import { css } from '@emotion/css'
import type { FC, ReactNode } from 'react'
import InjectLogo from '../../assets/inject-logo.svg?react'

const container = (
  position: 'left' | 'right' | undefined,
  width: number | undefined
) => css`
  display: flex;
  height: 100%;
  width: ${width}px;
  margin-left: ${position && position === 'left' ? '4px' : '0'};
  margin-right: ${position && position === 'right' ? '4px' : '0'};
`

const sidebar = css`
  flex: 1;
  margin: 4px 0;
  overflow-y: auto;
`

const sectionName = css`
  margin: 0 0 0.5rem 0.5rem;
  font-size: 1rem;
`

const sidebarTitle = css`
  margin: 0 0 0.5rem 0.5rem;
  font-size: 1.2rem;
  text-align: center;
`

export interface Section {
  name?: string
  node: ReactNode
}

interface SidebarProps {
  position?: 'left' | 'right'
  hideNames?: boolean
  width?: number
  sections: Section[]
  showLogo?: boolean
  title?: string
}

const Sidebar: FC<SidebarProps> = ({
  position,
  sections,
  showLogo,
  hideNames,
  width,
  title,
}) => (
  <div className={container(position, width)}>
    {position === 'right' && <Divider />}

    <div className={sidebar}>
      {title && (
        <div>
          <h2 className={sidebarTitle}>{title}</h2>
          <Divider />
        </div>
      )}

      {showLogo && (
        <>
          <InjectLogo
            style={{
              width: '69px',
              height: 'auto',
              padding: '5px 10px',
              display: 'block',
              margin: 'auto',
            }}
          />

          <Divider />
        </>
      )}

      {sections.map((section, index) => (
        <div key={index}>
          {!hideNames && section.name && (
            <h3 className={sectionName}>{section.name}</h3>
          )}
          {section.node}
          {index < sections.length - 1 && <Divider />}
        </div>
      ))}
    </div>

    {position === 'left' && <Divider />}
  </div>
)

export default Sidebar
