import { Button, Card, Overlay2 } from '@blueprintjs/core'
import { css } from '@emotion/css'
import type { EmailThread } from '@inject/graphql/fragments/EmailThread.generated'
import { useGetTeamEmailParticipant } from '@inject/graphql/queries/GetTeamEmailParticipant.generated'
import type { FC } from 'react'
import { useEffect, useState } from 'react'
import InstructorEmailForm from '../EmailForm/InstructorEmailForm'
import TraineeEmailForm from '../EmailForm/TraineeEmailForm'

const card = css`
  height: 50vh;
  width: 40vw;
  padding: 0 !important;
  display: flex;
  flex-direction: column;
  right: 1vw;
  bottom: 0;
`

export const OPEN_COMPOSE_EVENT_TYPE = 'openCompose'
export const OPEN_REPLY_EVENT_TYPE = 'openReply'

interface EmailFormOverlayProps {
  teamId: string
  emailForm: 'trainee' | 'instructor'
  exerciseId: string
}

interface OpenReplyEventPayload {
  emailThread: EmailThread
}

const EmailFormOverlay: FC<EmailFormOverlayProps> = ({
  teamId,
  emailForm,
  exerciseId,
}) => {
  const [open, setOpen] = useState(false)
  const [emailThread, setEmailThread] = useState<EmailThread | undefined>()

  const handleOpenCompose = () => {
    setOpen(true)
    setEmailThread(undefined)
  }
  useEffect(() => {
    window.addEventListener(OPEN_COMPOSE_EVENT_TYPE, handleOpenCompose)
    return () => {
      window.removeEventListener(OPEN_COMPOSE_EVENT_TYPE, handleOpenCompose)
    }
  }, [])

  const handleOpenReply = (event: CustomEvent<OpenReplyEventPayload>) => {
    setOpen(true)
    setEmailThread(event.detail.emailThread)
  }
  useEffect(() => {
    window.addEventListener(
      OPEN_REPLY_EVENT_TYPE,
      handleOpenReply as EventListener
    )
    return () => {
      window.removeEventListener(
        OPEN_REPLY_EVENT_TYPE,
        handleOpenReply as EventListener
      )
    }
  }, [])

  const { data: teamParticipantData } = useGetTeamEmailParticipant({
    variables: {
      teamId,
    },
    skip: !teamId,
  })
  const [teamAddress, setTeamAddress] = useState<string>(
    teamParticipantData?.teamEmailParticipant?.address || ''
  )
  useEffect(
    () =>
      setTeamAddress(teamParticipantData?.teamEmailParticipant?.address || ''),
    [teamParticipantData?.teamEmailParticipant?.address]
  )

  useEffect(() => {
    setOpen(false)
  }, [teamId])

  return (
    <Overlay2
      isOpen={open}
      autoFocus={false}
      canEscapeKeyClose={false}
      canOutsideClickClose={false}
      enforceFocus={false}
      hasBackdrop={false}
      transitionDuration={0}
    >
      <Card className={card} compact elevation={4}>
        <Button
          minimal
          icon='cross'
          style={{ marginLeft: 'auto' }}
          onClick={() => setOpen(false)}
        />
        {emailForm === 'trainee' ? (
          <TraineeEmailForm
            onFinish={() => setOpen(false)}
            teamId={teamId}
            exerciseId={exerciseId}
            teamAddress={teamAddress}
            emailThread={emailThread}
          />
        ) : (
          <InstructorEmailForm
            onFinish={() => setOpen(false)}
            teamId={teamId}
            exerciseId={exerciseId}
            emailThread={emailThread}
          />
        )}
      </Card>
    </Overlay2>
  )
}

export default EmailFormOverlay
