import type { EmailSelection } from '@/analyst/utilities'
import type { EmailThread } from '@inject/graphql/fragments/EmailThread.generated'
import type { FC } from 'react'
import TeamEmails from '.'

interface InstructorTeamEmailsProps {
  exerciseId: string
  teamId: string
  emailThreads: EmailThread[]
  selectedTab?: EmailSelection
  onSelectReceived?: () => void
  onSelectSent?: () => void
  selectedEmailThreadId: string | undefined
  onClick: (emailThread: EmailThread) => void
}

const InstructorTeamEmails: FC<InstructorTeamEmailsProps> = ({
  exerciseId,
  teamId,
  emailThreads,
  selectedTab,
  onSelectReceived,
  onSelectSent,
  selectedEmailThreadId,
  onClick,
}) => {
  const selectedEmailThread = emailThreads.find(
    emailThread => emailThread.id === selectedEmailThreadId
  )

  const replyDisabled =
    selectedEmailThread !== undefined &&
    !selectedEmailThread.participants.some(
      participant => participant.definitionAddress
    )

  return (
    <TeamEmails
      exerciseId={exerciseId}
      teamId={teamId}
      emailThreads={emailThreads}
      allowTabs
      selectedTab={selectedTab}
      onSelectReceived={onSelectReceived}
      onSelectSent={onSelectSent}
      selectedEmailThread={selectedEmailThread}
      onClick={onClick}
      allowComposing
      allowReplying={!replyDisabled}
      inInstructor
      replyButtonTitle={
        replyDisabled ? "You can't reply to emails between teams" : undefined
      }
    />
  )
}

export default InstructorTeamEmails
