import { Button, Classes } from '@blueprintjs/core'
import type { FC } from 'react'

interface ThreadHeaderCardProps {
  title: string
  subtitle?: string
  allowReplying: boolean
  replyButtonTitle?: string
  onReply?: () => void
}

const ThreadHeaderCard: FC<ThreadHeaderCardProps> = ({
  title,
  subtitle,
  allowReplying,
  replyButtonTitle,
  onReply,
}) => (
  <div style={{ display: 'flex', padding: '10px 20px 0' }}>
    <div>
      <h6 className={`${Classes.HEADING} ${Classes.SECTION_HEADER_TITLE}`}>
        {title}
      </h6>
      <div
        className={`${Classes.TEXT_MUTED} ${Classes.SECTION_HEADER_SUB_TITLE}`}
      >
        {subtitle}
      </div>
    </div>
    <div className={Classes.SECTION_HEADER_RIGHT}>
      <Button
        minimal
        intent='primary'
        text='Reply'
        icon='key-enter'
        onClick={onReply}
        disabled={!allowReplying}
        title={replyButtonTitle}
      />
    </div>
  </div>
)

ThreadHeaderCard.defaultProps = {
  subtitle: '',
}

export default ThreadHeaderCard
