import { EmailSelection, compareDates } from '@/analyst/utilities'
import { Button, ButtonGroup, Card, CardList, Divider } from '@blueprintjs/core'
import { css } from '@emotion/css'
import type { Email } from '@inject/graphql/fragments/Email.generated'
import type { EmailThread } from '@inject/graphql/fragments/EmailThread.generated'
import type { FC } from 'react'
import ThreadLogCard from './ThreadLogCard'

const threadLog = css`
  display: flex;
  flex-shrink: 10;
  flex-direction: column;
  overflow: auto;
  flex: 1;
`

const header = css`
  padding: 10px 20px 0;
  display: flex;
  flex-wrap: wrap;
  justify-content: space-between;
`

const cardList = css``

interface ThreadLogCardsProps {
  teamId: string
  emailThreads: EmailThread[]
  allowTabs?: boolean
  selectedTab?: EmailSelection
  onSelectReceived?: () => void
  onSelectSent?: () => void
  selectedEmailThreadId?: string
  onClick: (emailThread: EmailThread) => void
  inAnalyst?: boolean
  allowComposing?: boolean
  composeButtonTitle?: string
  onCompose?: () => void
}

const ThreadLogCards: FC<ThreadLogCardsProps> = ({
  teamId,
  emailThreads,
  allowTabs,
  selectedTab,
  onSelectReceived,
  onSelectSent,
  selectedEmailThreadId,
  onClick,
  inAnalyst,
  allowComposing,
  composeButtonTitle,
  onCompose,
}) => {
  const emailThreadsWithLastEmails: {
    emailThread: EmailThread
    lastEmail: Email
  }[] = []
  emailThreads.forEach(emailThread => {
    let lastEmail: Email | undefined | null

    if (!allowTabs) {
      lastEmail = emailThread.lastEmail
    } else {
      ;[...emailThread.emails]
        .sort(
          (a, b) => -compareDates(new Date(a.timestamp), new Date(b.timestamp))
        )
        .forEach(email => {
          if (!lastEmail) {
            if (
              selectedTab === EmailSelection.SENT
                ? email.sender.team?.id === teamId
                : email.sender.team?.id !== teamId
            ) {
              lastEmail = email
            }
          }
        })
    }

    if (!lastEmail) return

    emailThreadsWithLastEmails.push({
      emailThread,
      lastEmail,
    })
  })

  const threadLogCards = emailThreadsWithLastEmails
    .sort(
      (a, b) =>
        -compareDates(
          new Date(a.lastEmail.timestamp),
          new Date(b.lastEmail.timestamp)
        )
    )
    .map(element => (
      <ThreadLogCard
        key={element.emailThread.id}
        emailThread={element.emailThread}
        lastEmail={element.lastEmail}
        teamId={teamId}
        isSelected={element.emailThread.id === selectedEmailThreadId}
        onClick={() => onClick(element.emailThread)}
        inAnalyst={inAnalyst}
      />
    ))

  return (
    <div className={threadLog}>
      {allowTabs && (
        <>
          <div className={header}>
            <ButtonGroup minimal>
              <Button
                text='Received'
                icon='inbox'
                active={selectedTab === EmailSelection.RECEIVED}
                onClick={onSelectReceived}
              />
              <Divider />
              <Button
                text='Sent'
                icon='send-message'
                active={selectedTab === EmailSelection.SENT}
                onClick={onSelectSent}
              />
            </ButtonGroup>
            <div>
              <Button
                minimal
                intent='primary'
                text='Compose'
                icon='edit'
                onClick={onCompose}
                disabled={!allowComposing}
                title={composeButtonTitle}
              />
            </div>
          </div>

          <Divider />
        </>
      )}

      <CardList bordered={false} className={cardList}>
        {' '}
        {threadLogCards.length > 0 ? (
          threadLogCards
        ) : (
          <Card>{`No emails${
            selectedTab === undefined
              ? ''
              : ` ${selectedTab === EmailSelection.SENT ? 'sent' : 'received'}`
          }`}</Card>
        )}
      </CardList>
    </div>
  )
}

ThreadLogCards.defaultProps = {
  allowTabs: false,
  allowComposing: false,
  inAnalyst: false,
}

export default ThreadLogCards
