import { NumericInput } from '@blueprintjs/core'
import { css } from '@emotion/css'
import type { Dispatch, FC, SetStateAction } from 'react'

const gridContainer = css`
  display: grid;
  grid-template-columns: auto 1fr;
  grid-column-gap: 10px;
`

const gridItem = css`
  height: 30px;
  display: flex;
  align-items: center;
  font-size: 16px;
`

const REPEAT_MAX = 10

interface HeaderAreaProps {
  repeat: number | undefined
  setRepeat: Dispatch<SetStateAction<number | undefined>>
}

const HeaderArea: FC<HeaderAreaProps> = ({ repeat, setRepeat }) => (
  <div className={gridContainer}>
    <div className={gridItem}>Repeat:</div>
    <NumericInput
      fill
      placeholder='Extra Copies'
      min={0}
      max={REPEAT_MAX}
      value={repeat}
      onValueChange={value => {
        if (value <= REPEAT_MAX && value >= 0) {
          setRepeat(value)
        }
      }}
    />
  </div>
)

export default HeaderArea
