import ContentArea from '@/components/ContentArea'
import FileArea from '@/components/FileArea'
import { MainDrawer } from '@/email/EmailForm/css'
import { CUSTOM_INJECT_SELECTION_ID } from '@/utils'
import { Button, ButtonGroup, Divider, FormGroup } from '@blueprintjs/core'
import { css } from '@emotion/css'
import type { FileInfo } from '@inject/graphql/fragments/FileInfo.generated'
import { useSelectTeamInjectOption } from '@inject/graphql/mutations/SelectTeamInjectOption.generated'
import { useNotifyContext } from '@inject/shared/notification/contexts/NotifyContext'
import type { Dispatch, SetStateAction } from 'react'
import { useState } from 'react'
import InstructorInjectSelector from '../InstructorInjectSelector'
import MilestoneSelector from '../MilestoneSelector/MilestoneSelector'
import HeaderArea from './HeaderArea'

const header = css`
  margin-bottom: 1rem;
`

interface InjectComposerProps {
  teamId: string
  exerciseId: string
  setIsOpen: Dispatch<SetStateAction<boolean>>
}

const InjectForm = ({ teamId, exerciseId, setIsOpen }: InjectComposerProps) => {
  const { notify } = useNotifyContext()
  const [mutate, { loading }] = useSelectTeamInjectOption()

  const [repeat, setRepeat] = useState<number>()

  const [activateMilestone, setActivateMilestone] = useState<string>('')
  const [deactivateMilestone, setDeactivateMilestone] = useState<string>('')
  const [content, setContent] = useState('')

  const [fileInfo, setFileInfo] = useState<FileInfo>()

  const onSentSuccessfully = () => {
    notify(`Inject sent successfully`)
    setIsOpen(false)
  }

  const onSend = () => {
    mutate({
      variables: {
        selectTeamInjectInput: {
          teamId,
          selectionId: CUSTOM_INJECT_SELECTION_ID,
          optionEmail: false,
          content: content,
          activateMilestone,
          deactivateMilestone,
          fileId: fileInfo?.id,
          repeat,
        },
      },
    })
      .then(() => {
        onSentSuccessfully()
      })
      .catch(err => notify(`Error: ${err.message}`, { intent: 'danger' }))
  }

  return (
    <div className={MainDrawer}>
      <h3 className={header}>Pre-defined injects:</h3>
      <InstructorInjectSelector
        teamId={teamId}
        exerciseId={exerciseId}
        onSentSuccessfully={onSentSuccessfully}
      />

      <Divider style={{ margin: '1rem 0' }} />

      <h3 className={header}>Custom inject:</h3>

      <HeaderArea repeat={repeat} setRepeat={setRepeat} />

      <Divider style={{ margin: '0.5rem 0' }} />

      <MilestoneSelector
        teamId={teamId}
        activateMilestone={activateMilestone}
        setActivateMilestone={setActivateMilestone}
        deactivateMilestone={deactivateMilestone}
        setDeactivateMilestone={setDeactivateMilestone}
      />

      <ContentArea content={content} setContent={setContent} />

      <Divider style={{ margin: '0.5rem 0' }} />

      <div
        style={{
          display: 'flex',
          justifyContent: 'space-between',
        }}
      >
        <FileArea
          fileInfo={fileInfo}
          setFileInfo={setFileInfo}
          teamId={teamId}
        />

        <FormGroup disabled={loading} style={{ margin: '0' }}>
          <ButtonGroup>
            <Button icon='trash' onClick={() => setIsOpen(false)}>
              Discard
            </Button>
            <Button
              type='submit'
              rightIcon='send-message'
              onClick={onSend}
              disabled={loading}
            >
              {loading ? 'Sending...' : 'Send'}
            </Button>
          </ButtonGroup>
        </FormGroup>
      </div>
    </div>
  )
}

export default InjectForm
