import FileButton from '@/components/FileViewRedirectButton/FileButton'
import { Button, Card } from '@blueprintjs/core'
import { css } from '@emotion/css'
import type { InjectOption } from '@inject/graphql/fragments/InjectOption.generated'

const th = css`
  text-align: left;
  vertical-align: text-top;
  white-space: nowrap;
  width: 150px;
`

const td = css`
  white-space: pre-wrap;
  vertical-align: text-top;
  padding: 5px 10px;
`

const card = css`
  display: flex;
  flex-direction: column;
  justify-content: space-between;
  margin: 1rem;
`

interface InjectOptionGroupProps {
  onSend: () => void
  selectionId: string
  option: InjectOption
  loading: boolean
  teamId: string
  exerciseId: string
}

const InjectCardOption = ({
  onSend,
  selectionId,
  option,
  loading,
  teamId,
  exerciseId,
}: InjectOptionGroupProps) => (
  <Card key={selectionId} className={card}>
    <table>
      <tbody>
        <tr>
          <th className={th}>Name</th>
          <td className={td}>{option.name || '-'}</td>
        </tr>
        <tr>
          <th className={th}>Sender</th>
          <td className={td}>{option.sender || '-'}</td>
        </tr>
        <tr>
          <th className={th}>Activate milestones</th>
          <td className={td}>{option.control.activateMilestone || '-'}</td>
        </tr>
        <tr>
          <th className={th}>Deactivate milestones</th>
          <td className={td}>{option.control.deactivateMilestone || '-'}</td>
        </tr>
        <tr>
          <th className={th}>Content</th>
          <td
            className={td}
            aria-label='renderedContent'
            dangerouslySetInnerHTML={{
              __html: option.content.rendered || '-',
            }}
          />
        </tr>
        <tr>
          <th className={th}>Attached file</th>
          <td className={td}>
            {option.content.fileInfo ? (
              <FileButton
                fileInfo={option.content.fileInfo}
                teamId={teamId}
                exerciseId={exerciseId}
                allowRedirect={false}
              />
            ) : (
              '-'
            )}
          </td>
        </tr>
      </tbody>
    </table>

    <Button
      style={{ marginTop: '1rem', alignSelf: 'end' }}
      type='button'
      onClick={onSend}
      rightIcon='send-message'
    >
      {loading ? 'Sending...' : 'Send'}
    </Button>
  </Card>
)

InjectCardOption.defaultProps = {
  disabled: false,
}

export default InjectCardOption
