import { NonIdealState } from '@blueprintjs/core'
import { useGetTeamInjectSelections } from '@inject/graphql/queries/GetTeamInjectSelections.generated'
import notEmpty from '@inject/shared/utils/notEmpty'
import type { FC } from 'react'
import InjectOptionGroup from './InjectOptionGroup'

export interface InjectItemsProps {
  teamId: string
  exerciseId: string
  onSentSuccessfully: () => void
}

export const InjectItems: FC<InjectItemsProps> = ({
  teamId,
  exerciseId,
  onSentSuccessfully,
}) => {
  const { data } = useGetTeamInjectSelections({
    fetchPolicy: 'cache-only',
    variables: {
      teamId,
    },
  })

  const dataFiltered =
    data?.teamInjectSelections?.filter(notEmpty).filter(x => !x.submitted) || []

  if (dataFiltered.length === 0) {
    return (
      <NonIdealState
        title='No inject templates'
        description='No inject templates are currently available'
        icon='inbox-search'
      />
    )
  }

  return (
    <div
      style={{
        overflowY: 'scroll',
        overflowX: 'hidden',
      }}
    >
      {dataFiltered.map(selection => (
        <InjectOptionGroup
          key={selection.id}
          selection={selection}
          onSentSuccessfully={onSentSuccessfully}
          teamId={teamId}
          exerciseId={exerciseId}
        />
      ))}
    </div>
  )
}

export default InjectItems
