import ErrorMessage from '@/components/ErrorMessage'
import { Divider, NonIdealState, Spinner } from '@blueprintjs/core'
import { useGetTeamLearningObjectives } from '@inject/graphql/queries/GetTeamLearningObjectives.generated'
import Container from '@inject/shared/components/Container'
import notEmpty from '@inject/shared/utils/notEmpty'
import { useMemo, type FC } from 'react'
import LearningObjective from './LearningObjective'

interface LearningObjectivesProps {
  teamId: string
}

const LearningObjectives: FC<LearningObjectivesProps> = ({ teamId }) => {
  const { data, loading, error } = useGetTeamLearningObjectives({
    variables: { teamId },
  })
  const objectives = useMemo(
    () => data?.teamLearningObjectives?.filter(notEmpty) ?? [],
    [data]
  )

  if (loading) {
    return <Spinner />
  } else if (error) {
    return (
      <ErrorMessage>
        <h1>Error occurred!</h1>
        <p>{error.message}</p>
      </ErrorMessage>
    )
  } else if (!data || !data.teamLearningObjectives) {
    return (
      <NonIdealState
        icon='low-voltage-pole'
        title='No data'
        description='Please wait for the data to come in'
      />
    )
  }

  if (objectives.length === 0) {
    return (
      <NonIdealState
        icon='low-voltage-pole'
        title='No learning objectives'
        description='There are no learning objectives to display'
      />
    )
  }

  return (
    <Container>
      {objectives.map((objective, index) => (
        <div key={objective.id}>
          <LearningObjective objective={objective} teamId={teamId} />
          {index !== objectives.length - 1 && <Divider />}
        </div>
      ))}
    </Container>
  )
}

export default LearningObjectives
