import { useTeamStateMap } from '@/clientsettings/vars/teams'
import { useNavigate } from '@/router'
import { Button, ButtonGroup } from '@blueprintjs/core'
import { useGetRunningExercises } from '@inject/graphql/queries/GetRunningExercises.generated'
import type { FC } from 'react'
import Reloader from '../Reloader'

interface StaffSelectorInterface {
  enableRefresh?: boolean
}

const StaffSelector: FC<StaffSelectorInterface> = ({ enableRefresh }) => {
  const { data } = useGetRunningExercises()
  const teamStateMap = useTeamStateMap()
  const nav = useNavigate()

  const anyExerciseRunning = (data?.exercises?.length || 0) > 0

  return (
    <>
      <ButtonGroup large fill>
        <Button
          icon='intelligence'
          title={
            anyExerciseRunning
              ? 'Enter Instructor view'
              : 'Please wait for the administrator to start the exercises'
          }
          disabled={
            !anyExerciseRunning && Object.keys(teamStateMap).length === 0
          }
          onClick={() => nav('/instructor')}
        >
          Instructor
        </Button>
        <Button icon='series-search' onClick={() => nav('/analyst')}>
          Analyst
        </Button>
        {enableRefresh && <Reloader />}
      </ButtonGroup>
    </>
  )
}

export default StaffSelector
