import { formatTimestamp } from '@/analyst/utilities'
import { AccountStatus, UserGroup, type User } from '@/users/UserTable'
import { Button, HTMLSelect, Section, SectionCard } from '@blueprintjs/core'
import { css } from '@emotion/css'
import type { FC } from 'react'
import { useState } from 'react'

const detail = css`
  display: grid;
  grid-template-columns: 50% 50%;
  grid-column-gap: 10px;
`

const detailRow = css`
  padding-bottom: 0.75rem;
`

const detailRowName = css`
  font-weight: bolder;
  padding-right: 0.5rem;
`

interface UserDetailProps {
  userId: string
}

const UserDetail: FC<UserDetailProps> = ({ userId }) => {
  const user: User = {
    id: '1',
    email: 'email',
    userName: 'username',
    firstName: 'First',
    lastName: 'Last',
    group: UserGroup.TRAINEE,
    accountStatus: AccountStatus.DEACTIVATED,
    dateJoined: new Date(),
    exercises: ['exercise 1', 'exercise 2'],
  }

  const userGroups = Object.keys(UserGroup)
  const [userGroup, setUserGroup] = useState(user.group.toString())

  const accountStatuses = Object.keys(AccountStatus)
  const [accountStatus, setAccountStatus] = useState(
    user.accountStatus.toString()
  )

  return (
    <Section title={`User detail - ${userId}`}>
      <SectionCard>
        <div className={detail}>
          <div>
            <div className={detailRow}>
              <span className={detailRowName}>Email: </span> {user.email}
            </div>
            <div className={detailRow}>
              <span className={detailRowName}>Username: </span> {user.userName}
            </div>
            <div className={detailRow}>
              <span className={detailRowName}>First name: </span>{' '}
              {user.firstName}
            </div>
            <div className={detailRow}>
              <span className={detailRowName}>Last name: </span> {user.lastName}
            </div>
            <div className={detailRow}>
              <span className={detailRowName}>Date joined: </span>{' '}
              {formatTimestamp(user.dateJoined.toISOString())}
            </div>
            <div className={detailRow} style={{ display: 'flex' }}>
              <span className={detailRowName}>Group: </span>{' '}
              <HTMLSelect
                fill
                options={userGroups}
                value={userGroup}
                onChange={e => setUserGroup(e.target.value)}
              />
            </div>
            <div className={detailRow} style={{ display: 'flex' }}>
              <span className={detailRowName}>Account status: </span>{' '}
              <HTMLSelect
                fill
                options={accountStatuses}
                value={accountStatus}
                onChange={e => setAccountStatus(e.target.value)}
              />
            </div>
          </div>
          <div>
            <span className={detailRowName}>Exercises:</span>
            {user.exercises.map(exercise => (
              <div key={exercise}>
                {exercise} <Button minimal icon='annotation' />
              </div>
            ))}
          </div>
        </div>

        <Button type='button' intent='primary'>
          Save changes
        </Button>
      </SectionCard>
    </Section>
  )
}

export default UserDetail
