import InjectMessage from '@/actionlog/InjectMessage'
import ErrorMessage from '@/components/ErrorMessage'
import { useNavigate } from '@/router'
import { Button } from '@blueprintjs/core'
import { css } from '@emotion/css'
import { useGetSingleActionLog } from '@inject/graphql/queries/GetSingleActionLog.generated'
import Container from '@inject/shared/components/Container'
import useInInstructor from '@inject/shared/hooks/useInInstructor'
import type { FC } from 'react'

const wrapper = css`
  display: flex;
  flex-direction: column;
  align-items: flex-start;
  height: 100%;
  width: 100%;
`

interface InjectMessageViewProps {
  teamId: string
  exerciseId: string
  channelId: string
  actionLogId: string
}

const InjectMessageView: FC<InjectMessageViewProps> = ({
  teamId,
  exerciseId,
  channelId,
  actionLogId,
}) => {
  const { data } = useGetSingleActionLog({
    variables: {
      logId: actionLogId,
    },
  })
  const nav = useNavigate()
  const inInstructor = useInInstructor()

  if (!data || !data.actionLog) {
    return <ErrorMessage>Log not found</ErrorMessage>
  }

  return (
    <Container makeFullHeight>
      <div className={wrapper}>
        <Button
          icon='chevron-left'
          text='Back'
          minimal
          style={{ marginBottom: '0.25rem' }}
          onClick={() =>
            nav(
              `/${inInstructor ? 'instructor' : 'trainee'}/:exerciseId/:teamId/:channelId/info`,
              {
                params: {
                  teamId,
                  exerciseId,
                  channelId,
                },
              }
            )
          }
        />
        <InjectMessage
          exerciseId={exerciseId}
          teamId={teamId}
          fill
          actionLog={data.actionLog}
          inInstructor={inInstructor}
          allowFileRedirect
        />
      </div>
    </Container>
  )
}

export default InjectMessageView
