import { defineConfig } from 'vite'
import react from '@vitejs/plugin-react-swc'
import generouted from '@generouted/react-router/plugin'
import path from 'path'
import { visualizer } from 'rollup-plugin-visualizer'
import svgr from 'vite-plugin-svgr'
import { vitePluginGraphqlLoader } from 'vite-plugin-graphql-loader'
import * as child_process from 'child_process'

// https://vitejs.dev/config/
export default () => {
  // const dev = mode === 'development'

  if (process.env.GIT_ENABLED) {
    const commitDate = child_process
      .execSync('git log -1 --format=%cI')
      .toString()
      .trimEnd()
    const branchName = child_process
      .execSync('git rev-parse --abbrev-ref HEAD')
      .toString()
      .trimEnd()
    const commitHash = child_process
      .execSync('git rev-parse HEAD')
      .toString()
      .trimEnd()
    const lastCommitMessage = child_process
      .execSync('git show -s --format=%s')
      .toString()
      .trimEnd()

    process.env.VITE_GIT_COMMIT_DATE = commitDate
    process.env.VITE_GIT_BRANCH_NAME = branchName
    process.env.VITE_GIT_COMMIT_HASH = commitHash
    process.env.VITE_GIT_LAST_COMMIT_MESSAGE = lastCommitMessage
  } else {
    process.env.VITE_GIT_COMMIT_DATE = new Date().toISOString()
    process.env.VITE_GIT_BRANCH_NAME = 'No branch name'
    process.env.VITE_GIT_COMMIT_HASH = 'No commit hash'
    process.env.VITE_GIT_LAST_COMMIT_MESSAGE =
      'GIT_ENABLED is not set enabled, no git information available.'
  }

  console.log('Compiling for these env variables: ', process.env)

  return defineConfig({
    esbuild: {
      drop: ['console'],
    },
    plugins: [
      react({
        jsxImportSource: '@emotion/react',
        plugins: [['@swc/plugin-emotion', {}]],
        tsDecorators: true,
        devTarget: 'es2022',
      }),
      generouted(),
      //@ts-ignore
      visualizer(),
      vitePluginGraphqlLoader(),
      svgr({
        svgrOptions: {
          ref: true,
        },
      }),
    ],
    envPrefix: ['VITE_', 'INJECT_'],
    resolve: {
      alias: {
        '@': path.resolve(__dirname, './src'),
      },
    },
    define: {
      'globalThis.__DEV__': JSON.stringify(false),
    },
    css: {
      devSourcemap: true,
      modules: {
        localsConvention: 'camelCaseOnly',
      },
    },
    build: {
      cssCodeSplit: true,
      cssMinify: 'lightningcss',
      minify: 'terser',
      target: 'es2022',
      outDir: '../dist',
      rollupOptions: {
        input: {
          index: path.resolve(__dirname, 'index.html'),
        },
        output: {
          compact: true,
        }
      },
      terserOptions: {
        mangle: {
          eval: true,
          keep_fnames: false,
          keep_classnames: false,
          toplevel: true,
        },
        compress: {
          dead_code: true,
          // drop_console: true,
          drop_debugger: true,
          ecma: 2020,
          if_return: true,
        },
      }
    },
  })
}
