import { InMemoryCache } from '@apollo/client'
import type { StrictTypedTypePolicies } from './apollo-helpers'

const typePolicies: StrictTypedTypePolicies = {
  Query: {
    fields: {
      exerciseId: {
        read(_, { args, toReference }) {
          return toReference({
            __typename: 'ExerciseType',
            id: args?.exerciseId || '',
          })
        },
      },
      actionLog: {
        read(_, { args, toReference }) {
          return toReference({
            __typename: 'ActionLogType',
            id: args?.logId || '',
          })
        },
      },
      emailThread: {
        read(_, { args, toReference }) {
          return toReference({
            __typename: 'EmailThreadType',
            id: args?.threadId || '',
          })
        },
      },
    },
  },
  ActionLogType: {
    keyFields: ['id'],
  },
  EmailThreadType: {
    keyFields: ['id'],
  },
  EmailType: {
    keyFields: ['id'],
  },
  ExerciseType: {
    keyFields: ['id'],
    fields: {
      definition: {
        merge: true,
      },
    },
  },
  EmailTemplateType: {
    keyFields: ['id'],
  },
  InjectOptionType: {
    keyFields: ['id'],
  },
  InjectSelectionType: {
    keyFields: ['id'],
  },
  MilestoneType: {
    keyFields: ['id'],
  },
  TeamType: {
    keyFields: ['id'],
    fields: {
      exercise: {
        merge: true,
      },
    },
  },
}

const cache = new InMemoryCache({
  typePolicies,
})

export default cache
