import useInInstructor from '@inject/shared/hooks/useInInstructor'
import { reject } from 'lodash'
import { useEffect } from 'react'
import type { EmailThread } from '../fragments/EmailThread.generated'
import { useResetReadReceiptEmailThread } from '../mutations/clientonly/ResetReadReceiptEmailThread.generated'
import { useGetEmailThreads } from '../queries/GetEmailThreads.generated'
import type { EmailThreadsSubscription } from '../subscriptions/EmailThreads.generated'
import { EmailThreadsSubscriptionDocument } from '../subscriptions/EmailThreads.generated'

const useEmailThreadSubscription = (teamId: string) => {
  const isInstructor = useInInstructor()

  const query = useGetEmailThreads({
    variables: {
      teamId,
    },
    initialFetchPolicy: 'network-only',
    nextFetchPolicy: 'cache-first',
  })
  const [mutateReadThread] = useResetReadReceiptEmailThread()

  const { subscribeToMore, networkStatus } = query
  useEffect(
    () =>
      subscribeToMore({
        document: EmailThreadsSubscriptionDocument,
        variables: {
          teamId,
        },
        updateQuery: (prev, { subscriptionData }) => {
          // Note: this is a hack, because Codegen implicitly typecasts subscriptionData to the parent query type, this is not desired
          const retypedData =
            subscriptionData.data as unknown as EmailThreadsSubscription
          if (!retypedData) return prev

          const newEmailThread = retypedData.emailThreads?.emailThread
          if (!newEmailThread) return prev

          mutateReadThread({
            variables: {
              emailThreadId: newEmailThread.id,
            },
          })

          const oldEmailThreads = prev.emailThreads || []
          const oldEmailThread = oldEmailThreads.find(
            oldThread => oldThread?.id === newEmailThread.id
          )
          if (oldEmailThread?.emails.length === newEmailThread.emails.length)
            return prev

          const newEmailThreads = reject(
            oldEmailThreads,
            (oldThread: EmailThread) => oldThread.id === newEmailThread.id
          ) as EmailThread[]
          newEmailThreads.push(newEmailThread)

          return {
            ...prev,
            emailThreads: newEmailThreads,
          }
        },
      }),
    [teamId, subscribeToMore, isInstructor, mutateReadThread]
  )

  return {
    networkStatus,
    teamId,
  }
}

export default useEmailThreadSubscription
