import { useEffect } from 'react'
import { useGetTeamInjectSelections } from '../queries/GetTeamInjectSelections.generated'
import type { TeamInjectSelections } from '../subscriptions/TeamInjectSelections.generated'
import { TeamInjectSelectionsDocument } from '../subscriptions/TeamInjectSelections.generated'

const useTeamInjectSelectionsSubscription = (teamId: string) => {
  const query = useGetTeamInjectSelections({
    variables: {
      teamId,
    },
    fetchPolicy: 'network-only',
    nextFetchPolicy: 'cache-first',
  })

  const { subscribeToMore, networkStatus } = query

  useEffect(
    () =>
      subscribeToMore({
        document: TeamInjectSelectionsDocument,
        variables: {
          teamId,
        },
        updateQuery: (prev, { subscriptionData }) => {
          const retypedData =
            subscriptionData.data as unknown as TeamInjectSelections

          if (!retypedData) return prev
          const newInject = retypedData.injectSelection?.injectSelection
          const oldInjects = prev.teamInjectSelections || []
          if (newInject) {
            // notify(`New inject for team ${teamId} available: ${newInject.name}`)
            return {
              ...prev,
              teamInjectSelections: [...oldInjects, newInject],
            }
          }
          return prev
        },
      }),
    [teamId]
  )

  return {
    networkStatus,
    teamId,
  }
}

export default useTeamInjectSelectionsSubscription
