import { useApolloClient } from '@apollo/client'
import notEmpty from '@inject/shared/utils/notEmpty'
import { useEffect } from 'react'
import { GetTeamLearningObjectivesDocument } from '../queries/GetTeamLearningObjectives.generated'
import type { GetTeamMilestones } from '../queries/GetTeamMilestones.generated'
import { useGetTeamMilestones } from '../queries/GetTeamMilestones.generated'
import type { TeamMilestonesSubscriptionResult } from '../subscriptions/TeamMilestones.generated'
import { TeamMilestonesDocument } from '../subscriptions/TeamMilestones.generated'
import mergeMilestoneState from './mergeMilestoneState'

const useTeamMilestonesSubscription = (teamId: string) => {
  const query = useGetTeamMilestones({
    variables: {
      teamId,
    },
    fetchPolicy: 'network-only',
    nextFetchPolicy: 'cache-first',
  })

  const { subscribeToMore, networkStatus } = query
  const client = useApolloClient()

  useEffect(
    () =>
      subscribeToMore({
        document: TeamMilestonesDocument,
        variables: {
          teamId,
        },
        updateQuery: (prev, { subscriptionData }) => {
          const retypedData =
            subscriptionData as unknown as TeamMilestonesSubscriptionResult

          if (!retypedData) return prev
          const newInject = (
            retypedData.data?.milestones?.milestones || []
          ).filter(notEmpty)
          const oldInjects = (prev.teamMilestones || []).filter(notEmpty)
          if (newInject) {
            client.refetchQueries({
              include: [GetTeamLearningObjectivesDocument],
            })
            return {
              ...prev,
              teamMilestones: mergeMilestoneState(oldInjects, newInject),
            } as GetTeamMilestones
          }
          return prev
        },
      }),
    [teamId]
  )

  return {
    networkStatus,
    teamId,
  }
}

export default useTeamMilestonesSubscription
