import type { CSSProperties, FC } from 'react'
import { useMemo } from 'react'

interface ColorBoxProps {
  id: number
  style?: CSSProperties
  title?: string
}

export type COLOR_ENUM = 0 | 1 | 2 | 3 | 4 | 5 | 6 | 7 | 8 | 9
export const COLOR_AMOUNT = 10

const toColorenum = (id: number): COLOR_ENUM => (id % 10) as COLOR_ENUM
const ColorBox: FC<ColorBoxProps> = ({ id, style, title }) => {
  const color = useMemo(() => {
    switch (toColorenum(id)) {
      case 0:
        return '#981d10'
      case 1:
        return '#c73700'
      case 2:
        return '#b2a22f'
      case 3:
        return '#0080b8'
      case 4:
        return '#008271'
      case 5:
        return '#c73700'
      case 6:
        return '#905a9e'
      case 7:
        return '#5d7acc'
      case 8:
        return '#016721'
      case 9:
        return '#47468d'
      default:
        return '#ff0000'
    }
  }, [id])

  return (
    <div
      style={{
        width: '1.2rem',
        height: '1.2rem',
        borderRadius: '0.25rem',
        backgroundColor: color,
        display: 'inline-block',
        ...style,
      }}
      title={title}
    />
  )
}
ColorBox.defaultProps = {
  style: {},
}

export default ColorBox
