import { Tag } from '@blueprintjs/core'
import type { CSSProperties, FC } from 'react'
import { useEffect, useState } from 'react'

const RERENDER_INTERVAL_SECONDS = 10

const timedFormatter = (datetime: Date, minimal: boolean) => {
  const secs = (Date.now() - datetime.getTime()) / 1000
  if (secs < 10) {
    return 'Just now'
  }
  if (secs < 60) {
    return minimal ? '<1m ago' : 'Less than a minute ago'
  }
  const hours = Math.floor(secs / 3600)
  const minutes = Math.floor(secs / 60) % 60
  const hourString = minimal
    ? `${hours}h`
    : `${hours} ${hours > 1 ? 'hours' : 'hour'}`
  const minuteString = minimal
    ? `${minutes}m`
    : `${minutes % 60} ${minutes % 60 > 1 ? 'minutes' : 'minute'}`

  return `${hours > 0 ? hourString : ''} ${minutes > 0 ? minuteString : ''} ago`
}

interface TimestampProps {
  datetime: Date
  minimal?: boolean
  style?: CSSProperties
}

const Timestamp: FC<TimestampProps> = ({
  datetime,
  minimal = false,
  style,
}) => {
  const [time, setTime] = useState<string>('')

  useEffect(() => {
    setTime(timedFormatter(datetime, minimal))
    const interval = setInterval(() => {
      setTime(timedFormatter(datetime, minimal))
    }, RERENDER_INTERVAL_SECONDS * 1000)
    return () => {
      clearInterval(interval)
    }
  }, [datetime, minimal])

  return (
    <Tag minimal round style={style}>
      {time !== '' ? time : datetime.toLocaleTimeString()}
    </Tag>
  )
}
Timestamp.defaultProps = {
  minimal: false,
  style: {},
}

export default Timestamp
