import { Button } from '@blueprintjs/core'
import { useTranslation } from '@cyntler/react-doc-viewer/dist/esm/hooks/useTranslation'
import { PDFContext } from '@cyntler/react-doc-viewer/dist/esm/renderers/pdf/state'
import {
  setPDFPaginated,
  setZoomLevel,
} from '@cyntler/react-doc-viewer/dist/esm/renderers/pdf/state/actions'
import { css } from '@emotion/css'
import { useContext } from 'react'
import PDFPagination from './PDFPagination'

const pdfsticky = css`
  position: sticky;
  top: 0.5rem;
  left: 0;
  right: 0;
  z-index: 4;
  padding-left: 0.5rem;
  padding-right: 0.5rem;
  overflow: visible;
`

const pdfcontrol = css`
  display: flex;
  gap: 0.5rem;
  justify-content: flex-end;
  align-items: center;
  background-color: white;
  padding: 0.5rem;
  border-radius: 0.5rem;
  box-shadow: 0 0 0.5rem rgba(0, 0, 0, 0.2);

  .bp5-dark & {
    background-color: #2f343c;
  }
`

const PDFControls = () => {
  const { t } = useTranslation()
  const {
    state: {
      mainState,
      paginated,
      zoomLevel,
      numPages,
      zoomJump,
      defaultZoomLevel,
    },
    dispatch,
  } = useContext(PDFContext)

  const currentDocument = mainState?.currentDocument || null

  return (
    <div className={pdfsticky}>
      <div id='pdf-controls' className={pdfcontrol}>
        {paginated && numPages > 1 && <PDFPagination />}

        {currentDocument?.fileData && (
          <Button
            id='pdf-download'
            onClick={() => {
              const link = document.createElement('a')
              link.href = currentDocument?.fileData as string
              link.download = currentDocument?.fileName || currentDocument?.uri
              link.dispatchEvent(new MouseEvent('click'))
            }}
            title={t('downloadButtonLabel')}
            icon='cloud-download'
          />
        )}

        <Button
          id='pdf-zoom-out'
          onMouseDown={() => dispatch(setZoomLevel(zoomLevel - zoomJump))}
          icon='zoom-out'
        />

        <Button
          id='pdf-zoom-in'
          onMouseDown={() => dispatch(setZoomLevel(zoomLevel + zoomJump))}
          icon='zoom-in'
        />

        <Button
          id='pdf-zoom-reset'
          onMouseDown={() => dispatch(setZoomLevel(defaultZoomLevel))}
          disabled={zoomLevel === defaultZoomLevel}
          icon='zoom-to-fit'
        />

        {numPages > 1 && (
          <Button
            id='pdf-toggle-pagination'
            onMouseDown={() => dispatch(setPDFPaginated(!paginated))}
            icon={paginated ? 'header' : 'document'}
          />
        )}
      </div>
    </div>
  )
}

export default PDFControls
