import { Button, ButtonGroup, Divider } from '@blueprintjs/core'
import type { IDocument } from '@cyntler/react-doc-viewer'
import DocViewer, {
  BMPRenderer,
  GIFRenderer,
  HTMLRenderer,
  JPGRenderer,
  PNGRenderer,
  TIFFRenderer,
  TXTRenderer,
  VideoRenderer,
} from '@cyntler/react-doc-viewer'
import { css } from '@emotion/css'
import { useEffect, useMemo, type FC } from 'react'
import { useNavigate } from 'react-router-dom'
import PDFRenderer from './plugins/pdf'
import './viewer.global.css'

interface DocViewerProps {
  doc: Required<Omit<IDocument, 'fileData'>>
}

const grid = css`
  display: grid;
  grid-template-rows: 2rem 1fr;
  padding: 0.5rem;
  grid-gap: 1rem;
  height: 100vh;
`

/*
 * use only in views, where it occupies full 100vh of the height without padding or margins!
 */
const DocViewerComponent: FC<DocViewerProps> = ({ doc }) => {
  const docs: IDocument[] = [doc]
  const nav = useNavigate()

  useEffect(() => {
    if (doc.fileName.endsWith('.pdf')) {
      ;(
        document.getElementById('pdf-renderer')?.querySelectorAll('a') || []
      ).forEach(x => {
        x.setAttribute('target', '_blank')
      })
    }
  }, [doc])

  const plugins = useMemo(
    () => [
      BMPRenderer,
      HTMLRenderer,
      JPGRenderer,
      PDFRenderer,
      PNGRenderer,
      TIFFRenderer,
      TXTRenderer,
      GIFRenderer,
      VideoRenderer,
    ],
    []
  )

  return (
    <div className={grid}>
      <div>
        <ButtonGroup minimal>
          <Button
            intent='primary'
            icon='arrow-left'
            onClick={() => {
              nav(-1)
            }}
          >
            Back
          </Button>
          <Divider />
          <a href={doc.uri} target='_blank' rel='noreferrer'>
            <Button icon='import' type='button'>
              Download
            </Button>
          </a>
        </ButtonGroup>
      </div>
      <DocViewer documents={docs} pluginRenderers={plugins} />
    </div>
  )
}

export default DocViewerComponent
